# beautifulstew
> Takes care of boilerplate so you can focus on the real problems. 

![MIT](https://img.shields.io/dub/l/vibe-d.svg?style=flat-square)
![dependencies](https://img.shields.io/david/expressjs/express.svg?style=flat-square)
![python](https://img.shields.io/badge/python-3.6%2C3.7-blue.svg?style=flat-square)


*coming soon*

## Dependencies
As the name suggests, ``beautifulstew`` depends on ``BeautifulSoup``. Make sure you have installed ``bs4`` before using ``beautifulstew``.

OS X & Linux:

```
pip install bs4
```

## Installation

OS X & Linux:

*Coming soon to PyPi*
```
pip install beautifulstew
```

## Usage example

Import all with ``from beautifulstew import *``.
``xml_2_soup``, ``soup_maker``, ``get_all_css``, ``get_img_src``


## Release History

* 0.0.1
    * Initial release (still a work in progress)

## Meta

NPM – [email me](https://github.com/npmontgomery)

Distributed under the MIT license. See ``LICENSE`` for more information.


## Contributing

If you would like to contribute or have any suggestions on how to improve, just send me a private message!

<!-- Markdown link & img dfn's -->


